@@ -23,18 +23,19 @@
 # delete this exception statement from your version.
 
 from __future__ import annotations
+from typing import Optional
 import typing
 
-from gi.repository import GObject, Gtk, Handy
+from gi.repository import GObject, Gtk
 
+from gnomemusic.coreartist import CoreArtist
 from gnomemusic.widgets.albumwidget import AlbumWidget
 if typing.TYPE_CHECKING:
     from gnomemusic.application import Application
-    from gnomemusic.coreartist import CoreArtist
 
 
 @Gtk.Template(resource_path="/org/gnome/Music/ui/ArtistAlbumsWidget.ui")
-class ArtistAlbumsWidget(Handy.Clamp):
+class ArtistAlbumsWidget(Gtk.Box):
     """Widget containing all albums by an artist
 
     A vertical list of AlbumWidget, containing all the albums
@@ -48,57 +49,71 @@ class ArtistAlbumsWidget(Handy.Clamp):
 
     selection_mode = GObject.Property(type=bool, default=False)
 
-    def __init__(
-            self, coreartist: CoreArtist, application: Application) -> None:
+    def __init__(self, application: Application) -> None:
         """Initialize the ArtistAlbumsWidget
 
-        :param CoreArtist coreartist: The CoreArtist object
         :param Aplication application: The Application object
         """
         super().__init__()
 
         self._application = application
-        self._artist = coreartist
-        self._model = coreartist.props.model
-        self._player = self._application.props.player
+        self._coreartist: Optional[CoreArtist] = None
 
-        self._listbox.bind_model(self._model, self._add_album)
+    def _update_model(self) -> None:
+        if self._coreartist is not None:
+            self._listbox.bind_model(
+                self._coreartist.props.model, self._add_album)
 
     def _add_album(self, corealbum):
         row = Gtk.ListBoxRow()
         row.props.selectable = False
         row.props.activatable = False
-        row.props.can_focus = False
+        row.props.focusable = False
 
         widget = AlbumWidget(self._application)
         widget.props.corealbum = corealbum
-        widget.props.active_coreobject = self._artist
+        widget.props.active_coreobject = self._coreartist
         widget.props.show_artist_label = False
 
+        self._coreartist.bind_property(
+            "selected", corealbum, "selected",
+            GObject.BindingFlags.SYNC_CREATE)
         self.bind_property(
             'selection-mode', widget, 'selection-mode',
             GObject.BindingFlags.BIDIRECTIONAL
             | GObject.BindingFlags.SYNC_CREATE)
 
-        row.add(widget)
+        row.set_child(widget)
 
         return row
 
     def select_all(self) -> None:
         """Select all items"""
-        def toggle_selection(row: Gtk.ListBoxRow) -> None:
-            row.get_child().select_all()
-
-        self._listbox.foreach(toggle_selection)
+        if self._coreartist is not None:
+            self._coreartist.props.selected = True
 
     def deselect_all(self) -> None:
         """Deselect all items"""
-        def toggle_selection(row: Gtk.ListBoxRow) -> None:
-            row.get_child().deselect_all()
+        if self._coreartist is not None:
+            self._coreartist.props.selected = False
 
-        self._listbox.foreach(toggle_selection)
+    @GObject.Property(
+        type=CoreArtist, flags=GObject.ParamFlags.READWRITE, default=None)
+    def coreartist(self) -> CoreArtist:
+        """Current CoreArtist object
 
-    @GObject.Property(type=str, flags=GObject.ParamFlags.READABLE)
-    def artist(self) -> str:
-        """Artist name"""
-        return self._artist.props.artist
+        :param CoreArtist coreartist: The CoreArtist object
+        :rtype: CoreArtist
+        """
+        return self._coreartist
+
+    @coreartist.setter  # type: ignore
+    def coreartist(self, coreartist: CoreArtist) -> None:
+        """Sets the CoreArtist for the widget
+
+        :param CoreArtist coreartist: The CoreArtist to use
+        """
+        if self._coreartist is not coreartist:
+            self._coreartist = coreartist
+
+            self._update_model()
